<?php

namespace Drupal\kashing\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Utility\Html;
use Drupal\kashing\Entity\KashingAPI;

class KashingFailureController extends ControllerBase {

    public function page() {
        return array(
            '#type' => 'markup',
            '#markup' => $this->success_page(),
        );
    }

    public function success_page() {

        $config = \Drupal::config('kashing.settings');
        $success_page = $config->get('failure_page')? $config->get('failure_page') : '';

        $output = $success_page;

        $user_id = \Drupal::currentUser()->id();
        $is_admin = \Drupal\user\Entity\User::load($user_id)->hasRole('administrator');

        if (isset($_GET['kTransactionID'])) { // Proceed only if parameter is available in $_GET

            $transaction_id = $_GET[ 'kTransactionID' ];
            $kashing_api = new KashingAPI();

            $transaction_details = $kashing_api->api_get_transaction_error_details( $transaction_id );

            // Regular user output

            if ( isset( $transaction_details['gatewaymessage'] ) ) {
                $extra_class = ( isset( $transaction_details['nogateway'] ) ) ? ' no-gateway-message' : '';
                $output = '<div class="kashing-transaction-details kashing-gateway-message' . $extra_class . '"><p>';
                $output .= Html::escape( $transaction_details['gatewaymessage'] );
                $output .= '</p></div>';
            }

            // Extra details for admin users

            if ($is_admin) {
                $output .= '<div class="kashing-frontend-notice kashing-errors">';
                $output .= '<p><strong>' . t('Kashing payment failed.') . '</strong></p><p>' . t('Transaction details') . ':</p><ul>';
                $output .= '<li>' . t('Transaction ID') . ': <strong>' . Html::escape( $_GET['kTransactionID']) . '</strong></li>';
                if ($_GET['kResponse']) {
                    $output .= '<li>' . t('Response Code') . ': <strong>' . Html::escape( $_GET['kResponse']) . '</strong></li>';
                }
                if ($_GET['kReason']) {
                    $output .= '<li>' . t('Reason Code') . ': <strong>' . Html::escape( $_GET['kReason']) . '</strong></li>';
                }
                if (isset( $transaction_details['gatewaymessage'])) {
                    $output .= '<li>' . t('Gateway Message') . ': <strong>' . Html::escape( $transaction_details['gatewaymessage'] ) . '</strong></li>';
                }
                $output .= '</ul><p>' . t('This notice is displayed to site administrators only.') . '</p>';
                $output .= '</div>';
            }
        } elseif (isset($_GET['kError']))  {
            if ($is_admin) {
                $output .= '<div class="kashing-frontend-notice kashing-errors">';
                $output .= '<p><strong>' . t('Kashing payment failed.') . '</strong></p><p>' . t('Transaction details') . ':</p><ul>';
                if ($_GET['kResponse']) {
                    $output .= '<li>' . t('Response Code') . ': <strong>' . Html::escape( $_GET['kResponse']) . '</strong></li>';
                }
                if ($_GET['kReason']) {
                    $output .= '<li>' . t('Reason Code') . ': <strong>' . Html::escape( $_GET['kReason']) . '</strong></li>';
                }
                if (isset($_GET['kError'])) {
                    $output .= '<li>' . t('Error') . ': <strong>' . Html::escape( $_GET['kError'] ) . '</strong></li>';
                }
                $output .= '</ul><p>' . t('This notice is displayed to site administrators only.') . '</p>';
                $output .= '</div>';
            }
        }

        return $output;
    }

}