<?php

namespace Drupal\kashing\StackMiddleware;

use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\HttpKernelInterface;

/**
 * Performs a custom task.
 */
class KashingStackMiddleware implements HttpKernelInterface {

    /**
     * The wrapped HTTP kernel.
     *
     * @var \Symfony\Component\HttpKernel\HttpKernelInterface
     */
    protected $httpKernel;

    /**
     * Creates a HTTP middleware handler.
     *
     * @param \Symfony\Component\HttpKernel\HttpKernelInterface $kernel
     *   The HTTP kernel.
     */
    public function __construct(HttpKernelInterface $kernel) {
        $this->httpKernel = $kernel;
    }

    /**
     * {@inheritdoc}
     */
    public function handle(Request $request, $type = self::MASTER_REQUEST, $catch = TRUE) {

        $this->kashing_redirection_action();
        return $this->httpKernel->handle($request, $type, $catch);
    }

    private function kashing_redirection_action() {

        // Check if the Response and Reasoncode GET parameters exist in the URL

        $config = \Drupal::config('kashing.settings');
        $base_url = $config->get('base');

        $succes_page = $base_url . '/payment-success/';
        $failure_page = $base_url . '/payment-failure//';

        if (isset($_GET) && array_key_exists('Response', $_GET) && array_key_exists('Reason', $_GET)) {

            $return_page = false;

            // Determine the success or failure based on the response and reason code

            if ($_GET['Response'] == 1 && $_GET['Reason'] == 1 && $succes_page != '') { // Success
                $return_page = $succes_page;
            } elseif ($_GET['Response'] == 4) {
                $return_page = $failure_page;
            } elseif ($failure_page != '') {
                $return_page = $failure_page;
            }

            // If redirection page exists, make a redirection.

            if ($return_page) {


                $return_url = $return_page;

                // Forward parameters

                $url_parameters = 'kTransactionID=' . $_GET['TransactionID'] . '&kResponse=' . $_GET['Response'] . '&kReason=' . $_GET[ 'Reason' ];

                if (strpos( $return_url, '&' ) !== false) { // Already has parameters
                    $return_url .= '&' . $url_parameters;
                } else {
                    $return_url .= '?' . $url_parameters;
                }

                // Make a redirection
                $response = new RedirectResponse($return_url, 302);
                $response->send();

                exit; // No need to execute the rest of the code.
            }


        }



        return;

    }
}